CLARITE Documentation
=====================
:Version: |version|

CLeaning to Analysis: Reproducibility-based Interface for Traits and Exposures

.. toctree::
   :maxdepth: 2

   Hall Lab Homepage <https://www.hall-lab.org>
   CLARITE Github Repo <https://github.com/HallLab/clarite-python>
   motivation
   installation
   citation
   usage
   example
   complex_surveys

API Reference
-------------

If you are looking for information on a specific function, class or
method, this part of the documentation is for you.

.. toctree::
   :maxdepth: 2

   api

CLI Reference
-------------

Documentation for using the CLI

.. toctree::
   :maxdepth: 2

   cli

Additional Notes
----------------

Release History, etc

.. toctree::
   :maxdepth: 2

   release-history
